@@ -58,7 +58,7 @@ def run_kaks(sp_list,step1out,args,config,step4out,step5out,gene_pairs_idmap):
         arg_list=[]
 
         for pair in gene_pairs_idmap:
-            tmp=(pair,pepmap,cdsmap,KaKs_Calculator,Kaks_aligncmd,Epal2nal,op)
+            tmp=(pair,pepmap,cdsmap,KaKs_Calculator,Kaks_aligncmd,Epal2nal,trimal,op)
             arg_list.append(tmp)
         sh_pool=Pool(args.t)
         sh_pool.map(run_ks,arg_list)
@@ -82,7 +82,7 @@ def run_kaks(sp_list,step1out,args,config,step4out,step5out,gene_pairs_idmap):
         logging.info("ALL step5 kaks has done.")
 
 def run_ks(args):
-    sub_sh(args[0],args[1],args[2],args[3],args[4],args[5],args[6])
+    sub_sh(args[0],args[1],args[2],args[3],args[4],args[5],args[6],args[7])
 
 def sum_Ks(pair):
     out=[]
@@ -96,7 +96,7 @@ def sum_Ks(pair):
     out=[pair[1],pair[0],pair[2],pair[3],kaks[2],kaks[3],kaks[4],dtv[1]]
     return out
 
-def sub_sh(pair,pepmap,cdsmap,KaKs_Calculator,Kaks_aligncmd,Epal2nal,op):
+def sub_sh(pair,pepmap,cdsmap,KaKs_Calculator,Kaks_aligncmd,Epal2nal,trimal,op):
     out=[]
     home_dir=os.path.dirname(os.path.abspath(__file__))
     try:
