@@ -11,7 +11,7 @@ def run_phymcl(step1out,phymcl,args,options,step2out):
         op=' '.join((op,' '.join((k,v))))
     step2_sh=open(os.sep.join([step2out,'step2.sh']),"w")
     step2_sh.write(phymcl+ " -in " +os.sep.join([step1out,'all_blastp.out'])+" -threads "+ str(args.t) + " -length " + os.sep.join([step1out,'all_sample.faa.length']) +
-                        " -species " + os.sep.join([step1out,'all_sample2fa.list']) + " -tree " + args.tree + " -out " + os.sep.join([step2out,'allmcl.out'])+"\n")
+                        " -species " + os.sep.join([step1out,'all_sample2fa.list']) + " -tree " + os.sep.join([step2out,"phymcl.input.tree"]) + " -out " + os.sep.join([step2out,'allmcl.out'])+"\n")
     step2_sh.close()
     if not args.only_script:
         try:
